MnemosynePostgres.Queries.MetadataQueries (mnemosyne_postgres v0.1.1)

Copy Markdown View Source

Ecto query builders for the node metadata table.

Summary

Functions

Base query scoped to the current tenant.

Filters the query to only include rows matching the given node IDs.

Returns the {table_name, schema} source tuple for the metadata table.

Functions

base(state)

@spec base(map()) :: Ecto.Query.t()

Base query scoped to the current tenant.

by_node_ids(query, node_ids)

@spec by_node_ids(Ecto.Query.t(), [String.t()]) :: Ecto.Query.t()

Filters the query to only include rows matching the given node IDs.

source(map)

@spec source(map()) :: {String.t(), module()}

Returns the {table_name, schema} source tuple for the metadata table.